.. _axes_grid-api-index:

####################################
The Matplotlib axes_grid Toolkit API
####################################

:Release: |version|
:Date: |today|

.. currentmodule:: mpl_toolkits

Axes Grid
---------
.. note::
   
   There is an older version of the AxesGrid toolkit, ``axes_grid`` (instead of
   ``axes_grid1``).  The old version had a single namespace for all axes_grid
   objects, and in the new version this toolkit was broken
   into the two modules below. For the documentation on ``axes_grid``,
   see the `previous version of the docs 
   <https://matplotlib.org/2.0.1/mpl_toolkits/axes_grid/index.html#toolkit-axesgrid-index>`_.

.. autosummary::
   :toctree: ../_as_gen
   :template: automodule.rst

   axes_grid1
   axisartist
